==> sensei-image-api-1.0.3.tgz: package/src/modules/etika.js <==
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))


    let image = await superagent.get(req.query.url).catch(err => { if (err) return res.send(JSON.stringify({ error: 'Failed receiving the image. Check the URL and make sure the image is valid.' })) });
    let img = await sharp(image.body).resize(665, 425).max().toBuffer();
    let etika = await sharp('./images/etika/etika.png').toBuffer();

    let first = await sharp('./images/etika/etikaDummy.png')
        .overlayWith(img, { top: 0, left: 407 })
        .toBuffer();

    sharp(first)
        .overlayWith(etika)
        .toBuffer((err, data, info) => {
            if (err) {
                res.setHeader('Content-Type', 'application/json');
                res.send(JSON.stringify({
                    error: err
                }));
                return;
            }
            res.setHeader('Content-Type', 'image/png'); res.end(data)
        });

};

==> sensei-image-api-1.2.0.tgz: package/src/modules/etika.js <==
const path = require('path');
const superagent = require('superagent');
const fs = require('fs');
const sharp = require('sharp');

module.exports = async (req, res) => {
    if (!req.query.url) {
        res.setHeader('Content-Type', 'application/json');
        res.send(JSON.stringify({
            error: 'URL is required!'
        }))
        return;
    }
    let url = req.query.url;
    if (!url.includes('http') && !url.includes('.')) {
        res.send(JSON.stringify({
            error: 'A valid URL must be provided!'
        }))
        return;
    }

    if ((!url.toLowerCase().includes('.png')) && (!url.toLowerCase().includes('.gif')) && (!url.toLowerCase().includes('.jpg')) && (!url.toLowerCase().includes('.jpeg'))) return res.send(JSON.stringify({
        error: 'This is not a valid image!'
    }))


    let image = await superagent.get(req.query.url).catch(err => { if (err) return res.send(JSON.stringify({ error: 'Failed receiving the image. Check the URL and make sure the image is valid.' })) });
    let img = await sharp(image.body).resize(665, 425).max().toBuffer();
    let etika = await sharp(`${path.dirname(require.main.filename)}/images/etika/etika.png`).toBuffer();

    let first = await sharp(`${path.dirname(require.main.filename)}/images/etika/etikaDummy.png`)
        .overlayWith(img, { top: 0, left: 407 })
        .toBuffer();

    sharp(first)
        .overlayWith(etika)
        .toBuffer((err, data, info) => {
            if (err) {
                res.setHeader('Content-Type', 'application/json');
                res.send(JSON.stringify({
                    error: err
                }));
                return;
            }
            res.setHeader('Content-Type', 'image/png'); res.end(data)
        });

};
